From f0e14c5f66c9c137b3e9ffea30acdcfdaa98b2af Mon Sep 17 00:00:00 2001
From: Anatoly Burakov <anatoly.burakov@intel.com>
Date: Mon, 16 Jun 2014 14:05:28 +0200
Subject: [PATCH] tools: rename igb_uio_bind to dpdk_nic_bind

Renaming the igb_uio_bind script to dpdk_nic_bind to have a generic name
before supporting two drivers.

Signed-off-by: Anatoly Burakov <anatoly.burakov@intel.com>
Acked-by: Thomas Monjalon <thomas.monjalon@6wind.com>
---
 tools/{igb_uio_bind.py => dpdk_nic_bind.py} |  0
 tools/setup.sh                              | 16 ++++++++--------
 2 files changed, 8 insertions(+), 8 deletions(-)
 rename tools/{igb_uio_bind.py => dpdk_nic_bind.py} (100%)

diff --git a/tools/igb_uio_bind.py b/tools/dpdk_nic_bind.py
similarity index 100%
rename from tools/igb_uio_bind.py
rename to tools/dpdk_nic_bind.py
diff --git a/tools/setup.sh b/tools/setup.sh
index c3fbd4dea2..a54f65d1e4 100755
--- a/tools/setup.sh
+++ b/tools/setup.sh
@@ -324,13 +324,13 @@ grep_meminfo()
 }
 
 #
 # Calls igb_uio_bind.py --status to show the NIC and what they
 # are all bound to, in terms of drivers.
 #
 show_nics()
 {
 	if  /sbin/lsmod  | grep -q igb_uio ; then
-		${RTE_SDK}/tools/igb_uio_bind.py --status
+		${RTE_SDK}/tools/dpdk_nic_bind.py --status
 	else
 		echo "# Please load the 'igb_uio' kernel module before querying or "
 		echo "# adjusting NIC device bindings"
@@ -338,16 +338,16 @@ show_nics()
 }
 
 #
 # Uses igb_uio_bind.py to move devices to work with igb_uio
 #
 bind_nics()
 {
 	if  /sbin/lsmod  | grep -q igb_uio ; then
-		${RTE_SDK}/tools/igb_uio_bind.py --status
+		${RTE_SDK}/tools/dpdk_nic_bind.py --status
 		echo ""
 		echo -n "Enter PCI address of device to bind to IGB UIO driver: "
 		read PCI_PATH
-		sudo ${RTE_SDK}/tools/igb_uio_bind.py -b igb_uio $PCI_PATH && echo "OK"
+		sudo ${RTE_SDK}/tools/dpdk_nic_bind.py -b igb_uio $PCI_PATH && echo "OK"
 	else
 		echo "# Please load the 'igb_uio' kernel module before querying or "
 		echo "# adjusting NIC device bindings"
@@ -355,18 +355,18 @@ bind_nics()
 }
 
 #
 # Uses igb_uio_bind.py to move devices to work with kernel drivers again
 #
 unbind_nics()
 {
-	${RTE_SDK}/tools/igb_uio_bind.py --status
+	${RTE_SDK}/tools/dpdk_nic_bind.py --status
 	echo ""
 	echo -n "Enter PCI address of device to bind to IGB UIO driver: "
 	read PCI_PATH
 	echo ""
 	echo -n "Enter name of kernel driver to bind the device to: "
 	read DRV
-	sudo ${RTE_SDK}/tools/igb_uio_bind.py -b $DRV $PCI_PATH && echo "OK"
+	sudo ${RTE_SDK}/tools/dpdk_nic_bind.py -b $DRV $PCI_PATH && echo "OK"
 }
 
 #
@@ -324,13 +324,13 @@ grep_meminfo()
 
 #
-# Calls igb_uio_bind.py --status to show the NIC and what they
+# Calls dpdk_nic_bind.py --status to show the NIC and what they
 # are all bound to, in terms of drivers.
 #
@@ -338,16 +338,16 @@ show_nics()
 
 #
-# Uses igb_uio_bind.py to move devices to work with igb_uio
+# Uses dpdk_nic_bind.py to move devices to work with igb_uio
 #
 bind_nics()
@@ -355,18 +355,18 @@ bind_nics()
 
 #
-# Uses igb_uio_bind.py to move devices to work with kernel drivers again
+# Uses dpdk_nic_bind.py to move devices to work with kernel drivers again
 #
 unbind_nics()
-- 
2.39.5